@@ -83,7 +83,16 @@ class IPv4(IP, Protocol):          # IETF RFC 791
         return self.protocol_numbers.get(self.proto, None)
 
     @property
-    def flags_txt(self) -> str:
+    def chksum_hex_str(self) -> str:
+        """
+        Gets a string representation of the hexadecimal value of the
+        IP checksum value set on the header.
+        Ex: From 62030 to '0xf24e'
+        """
+        return self.int_to_hex_str(self.chksum)
+    
+    @property
+    def flags_str(self) -> str:
         """
         Gets a string representation of the name of the IP flag set on
         the packet.
@@ -134,3 +143,11 @@ class IPv6(IP, Protocol):           # IETF RFC 2460 / 8200
     @property
     def encapsulated_proto(self) -> str:
         return self.protocol_numbers.get(self.next_header, None)
+
+    @property
+    def tclass_str(self):
+        return self.int_to_hex_str(self.tclass)
+
+    @property
+    def flabel_str(self):
+        return self.int_to_hex_str(self.flabel)
